# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Period'
        db.create_table('downtime_period', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('start_time', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('end_time', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('enabled', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('downtime', ['Period'])


    def backwards(self, orm):
        # Deleting model 'Period'
        db.delete_table('downtime_period')


    models = {
        'downtime.period': {
            'Meta': {'object_name': 'Period'},
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'end_time': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'start_time': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['downtime']


from django.db.models import Manager
from django.db.models.query import QuerySet
from datetime import datetime

class PeriodQuerySet(QuerySet):

    def active(self):
        return self.filter(enabled=True)

    def is_down(self):
        return self.filter(start_time__lte=datetime.now(), end_time__gte=datetime.now())

class PeriodManager(Manager):
    def get_query_set(self):
        return PeriodQuerySet(self.model, using=self._db)

    def active(self):
        return self.get_query_set().active()

    def is_down(self):
        return self.get_query_set().active().is_down()



from datetime import datetime
from downtime.models import Period
from django.shortcuts import render, redirect
from django.conf import settings

class DowntimeMiddleware(object):
    def process_request(self, request):
        exempt_paths = getattr(settings, 'DOWNTIME_EXEMPT_PATHS', ('/admin'))
        for path in exempt_paths:
            if request.path.startswith(path):
                return None

        now = datetime.now()
        objects = Period.objects.is_down()
        if objects.count() > 0:
            # we are down.
            url_redirect = getattr(settings, 'DOWNTIME_URL_REDIRECT', None)
            if url_redirect:
                return redirect(url_redirect)
            else:
                return render(request, "downtime/downtime.html")




from setuptools import setup, find_packages

version = '0.3'

setup(name='django-downtime',
      version=version,
      description="Give your site a down page, or redirect to another error page.",
      long_description=open("README.md", "r").read(),
      classifiers=[
                   "Development Status :: 5 - Production/Stable",
                   "Environment :: Web Environment",
                   "Intended Audience :: End Users/Desktop",
                   "Natural Language :: English",
                   "Operating System :: OS Independent",
                   "Framework :: Django",
                   "Programming Language :: Python",
                   "Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries",
                   "Topic :: Utilities",
                   "License :: OSI Approved :: MIT License",
                   ],
      keywords='',
      author='Derek Stegelman',
      author_email='dstegelman@gmail.com',
      url='http://github.com/dstegelman/django-downtime',
      license='MIT',
      packages=find_packages(),
      install_requires = [],
      include_package_data=True,
      zip_safe=False,
      )